This might be useful for package developers hoping to use need()
in their package, and looking for good candidates for dependencies which
could be moved from Imports to Suggests in the DESCRIPTION file.
Dependencies are searched for in two ways:
import() and importFrom() statements in the package's NAMESPACE
file, such as those created by @import and @importFrom tags if
creating package documentation with roxygen2
Functions called by using :: or ::: to access a dependency's namespace
directly
This approach isn't perfect, but it should capture most dependency uses.